@@ -20,11 +20,13 @@ from pandas.testing import assert_frame_equal
 
 import pytest
 import scipy.io as sio
-import sys
+import sys, json
 import os
 import pathlib
 test_dirpath = pathlib.Path(__file__).parent.absolute()
 
+from urllib.request import urlopen
+
 import pyleoclim as pyleo
 from pyleoclim.utils.tsmodel import (
     ar1_sim,
@@ -52,12 +54,14 @@ def gen_colored_noise(alpha=1, nt=100, f0=None, m=None, seed=None):
     return t, v
     
 def load_data():
+    # note: JEG swapped the two choices on 03/07/2022 to get through PaleoHack 3. 
+    # Awaits fixing of jsonutils (issue 209)
     try:
+        d = pyleo.utils.jsonutils.json_to_Scalogram('../../example_data/scal_signif_benthic.json')
+    except:
         url = 'https://raw.githubusercontent.com/LinkedEarth/Pyleoclim_util/Development/example_data/scal_signif_benthic.json'
         response = urlopen(url)
         d = json.loads(response.read())
-    except:
-        d = pyleo.utils.jsonutils.json_to_Scalogram('./example_data/scal_signif_benthic.json')
     return d
 
 # Tests below
@@ -483,7 +487,7 @@ class TestUiSeriesSummaryPlot:
         Passing just a pre generated psd.
         '''
         scal = load_data()
-        ts = scal.timeseries
+        ts = scal.__dict__['timeseries']
         fig, ax = ts.summary_plot()
     
         plt.close(fig)  
@@ -495,7 +499,7 @@ class TestUiSeriesSummaryPlot:
         Passing just a pre generated psd.
         '''
         scal = load_data()
-        ts = scal.timeseries
+        ts = scal.__dict__['timeseries']
         fig, ax = ts.summary_plot(
             scalogram = scal
         )
@@ -509,7 +513,7 @@ class TestUiSeriesSummaryPlot:
         Passing just a pre generated psd.
         '''
         scal = load_data()
-        ts = scal.timeseries
+        ts = scal.__dict__['timeseries']
         psd = ts.spectral(scalogram=scal)
         fig, ax = ts.summary_plot(
             psd = psd
@@ -524,7 +528,7 @@ class TestUiSeriesSummaryPlot:
         Passing just a pre generated psd.
         '''
         scal = load_data()
-        ts = scal.timeseries
+        ts = scal.__dict__['timeseries']
         fig, ax = ts.summary_plot(
             scalogram = scal, psd_method='lomb_scargle'
         )
